============
Installation
============


Through pip
-----------
::

    $ pip install gems


Via GitHub
----------
::

    $ git clone http://github.com/bprinty/gems.git
    $ cd gems
    $ python setup.py install


Questions/Feedback
------------------

File an issue in the `GitHub issue tracker <https://github.com/bprinty/animation/issues>`_.